MethodDescriptor

Trait MethodDescriptor 

pub trait MethodDescriptor:
    Clone
    + Copy
    + Debug
    + Send
    + Sync {
    // Required methods
    fn name(&self) -> &'static str;
    fn proto_name(&self) -> &'static str;
    fn input_type(&self) -> TypeId;
    fn input_proto_type(&self) -> &'static str;
    fn output_type(&self) -> TypeId;
    fn output_proto_type(&self) -> &'static str;
}
A descriptor for a method available on an RPC service.

Required Methods

fn name(&self) -> &'static str

The name of the service, used in Rust code and perhaps for human readability.

fn proto_name(&self) -> &'static str

The raw protobuf name of the service.

fn input_type(&self) -> TypeId

The Rust TypeId for the input that this method accepts.

fn input_proto_type(&self) -> &'static str

The raw protobuf name for the input type that this method accepts.

fn output_type(&self) -> TypeId

The Rust TypeId for the output that this method produces.

fn output_proto_type(&self) -> &'static str

The raw protobuf name for the output type that this method produces.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors